@@ -37,6 +37,7 @@ class Directive:
         self.file = element.get('file')
         self.linenr = element.get('linenr')
 
+
 class ValueType:
     """
     ValueType class. Contains (promoted) type information for each node in the AST.
@@ -70,10 +71,11 @@ class ValueType:
         self.typeScope = IdMap[self.typeScopeId]
 
     def isIntegral(self):
-        return self.type == 'bool' or self.type == 'char' or self.type == 'short' or self.type == 'int' or self.type == 'long' or self.type == 'long long'
+        return self.type in {'bool', 'char', 'short', 'int', 'long', 'long long'}
 
     def isFloat(self):
-        return self.type == 'float' or self.type == 'double' or self.type == 'long double'
+        return self.type in {'float', 'double', 'long double'}
+
 
 class Token:
     """
@@ -129,7 +131,6 @@ class Token:
     @endcode
     """
 
-
     Id = None
     str = None
     next = None
@@ -302,7 +303,6 @@ class Scope:
         self.nestedIn = IdMap[self.nestedInId]
 
 
-
 class Function:
     """
     Information about a function
@@ -391,7 +391,6 @@ class Variable:
         self.typeEndToken = IdMap[self.typeEndTokenId]
 
 
-
 class ValueFlow:
     """
     ValueFlow::Value class
@@ -404,7 +403,6 @@ class ValueFlow:
         values    Possible values
     """
 
-
     Id = None
     values = None
 
@@ -438,7 +436,6 @@ class ValueFlow:
             self.values.append(ValueFlow.Value(value))
 
 
-
 class Configuration:
     """
     Configuration class
@@ -502,9 +499,7 @@ class Configuration:
                 for values in element:
                     self.valueflow.append(ValueFlow(values))
 
-        IdMap = {}
-        IdMap[None] = None
-        IdMap['0'] = None
+        IdMap = {None: None, '0': None}
         for token in self.tokenlist:
             IdMap[token.Id] = token
         for scope in self.scopes:
@@ -619,20 +614,16 @@ class CppcheckData:
                     tok = Token(node)
                     tok.file = files[int(node.get('fileIndex'))]
                     self.rawTokens.append(tok)
-            for i in range(len(self.rawTokens)):
-                if i > 0:
-                    self.rawTokens[i].previous = self.rawTokens[i-1]
-                if i + 1 < len(self.rawTokens):
-                    self.rawTokens[i].next = self.rawTokens[i+1]
-
+            for i in range(len(self.rawTokens) - 1):
+                self.rawTokens[i + 1].previous = self.rawTokens[i]
+                self.rawTokens[i].next = self.rawTokens[i + 1]
 
         # root is 'dumps' node, each config has its own 'dump' subnode.
         for cfgnode in data.getroot():
-            if cfgnode.tag=='dump':
+            if cfgnode.tag == 'dump':
                 self.configurations.append(Configuration(cfgnode))
 
 
-
 def parsedump(filename):
     """
     parse a cppcheck dump file
@@ -640,7 +631,6 @@ def parsedump(filename):
     return CppcheckData(filename)
 
 
-
 def astIsFloat(token):
     """
     Check if type of ast node is float/double
@@ -650,10 +640,8 @@ def astIsFloat(token):
         return False
     if token.str == '.':
         return astIsFloat(token.astOperand2)
-    if '+-*/%'.find(token.str) == 0:
-        if True == astIsFloat(token.astOperand1):
-            return True
-        return astIsFloat(token.astOperand2)
+    if token.str in '+-*/%':
+        return astIsFloat(token.astOperand1) or astIsFloat(token.astOperand2)
     if not token.variable:
         # float literal?
         if token.str[0].isdigit():
@@ -682,6 +670,7 @@ class CppCheckFormatter(argparse.HelpFormatter):
             return text[2:].splitlines()
         return argparse.HelpFormatter._split_lines(self, text, width)
 
+
 def ArgumentParser():
     """
         Returns an argparse argument parser with an already-added
@@ -697,7 +686,8 @@ def ArgumentParser():
                         "Pre-defined templates: gcc, vs, edit")
     return parser
 
-def reportError(template, callstack=[], severity='', message='', id=''):
+
+def reportError(template, callstack=(), severity='', message='', id=''):
     """
         Format an error message according to the template.
 
@@ -715,7 +705,7 @@ def reportError(template, callstack=[], severity='', message='', id=''):
     elif template == 'edit':
         template = '{file} +{line}: {severity}: {message}'
     # compute 'callstack}, {file} and {line} replacements
-    stack = ' -> '.join(['[' + f + ':' + str(l) + ']' for (f, l) in callstack])
+    stack = ' -> '.join('[' + f + ':' + str(l) + ']' for (f, l) in callstack)
     file = callstack[-1][0]
     line = str(callstack[-1][1])
     # format message
